@@ -362,11 +362,13 @@ class Rad(QWidget):
         # We roll back the circle to the top level
         #: The trail we walked - traverse in reverse to get back to the upper layout. 
         clicktrail = [] 
+        # store current items as item list
+        #: The current upper layout
+        items_upper = [(label.icon, label.action) for label in self.circle]
+        # And reshape the circle, so it corresponds to the layout we want to save
+        self.arrange_in_circle(items)
         # The center can't change, so we can use the one from the previous version of the circle.
         while self.circle[0].action is not None:
-            # store current items as item list
-            #: The current upper layout
-            items_upper = [(label.icon, label.action) for label in self.circle]
             #: Items in the current folder, not for the circle!
             items_folder = items_upper
             # replace the first with a generic center.
@@ -399,6 +401,10 @@ class Rad(QWidget):
             if not found_the_folder:
                 print "Gah!"
                 return False
+            # store current items as item list again
+            #: The current upper layout
+            items_upper = [(label.icon, label.action) for label in self.circle]
+
 
         items_new = [(i.icon, i.action) for i in self.circle]
         # Now we walk back on the clicktrail
